@@ -810,6 +810,8 @@ struct TraceEnt *cachedtrace; /* from signalwindow.c 410 */
 struct TraceEnt *shift_click_trace; /* from signalwindow.c 411 */
 int trtarget_signalwindow_c_1; /* from signalwindow.c 412 */
 Trptr starting_unshifted_trace; /* from signalwindow.c */
+unsigned char standard_trace_dnd_degate; /* from signalwindow.c */
+unsigned char use_standard_trace_select; /* from signalwindow.c */
 unsigned char use_standard_clicking; /* from signalwindow.c */
 unsigned char std_collapse_pressed; /* from signalwindow.c */
 unsigned char std_dnd_tgt_on_signalarea; /* from signalwindow.c */
@@ -1203,6 +1205,7 @@ int busycnt_vzt_c_2; /* from vzt.c 641 */
 /*
  * wavewindow.c
  */
+char highlight_wavewindow; /* from wavewindow.c */
 char alt_wheel_mode; /* from wavewindow.c */
 char use_scrollwheel_as_y; /* from wavewindow.c */
 char enable_slider_zoom; /* from wavewindow.c */
