@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003-2011 Tony Bybell.
+ * Copyright (c) 2003-2012 Tony Bybell.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -1134,6 +1134,12 @@ return(lt ? lt->timescale : 0);
 }
 
 
+_VZT_RD_INLINE vztsint64_t vzt_rd_get_timezero(struct vzt_rd_trace *lt)
+{
+return(lt ? lt->timezero : 0);
+}
+
+
 /*
  * extract facname from prefix-compressed table.  this
  * performs best when extracting facs with monotonically
@@ -1765,7 +1771,30 @@ if(!(lt->handle=fopen(name, "rb")))
 		vzt_rd_pthread_mutex_init(lt, &lt->mutex, NULL);
 
 		rcf = fread(&lt->numfacs, 4, 1, lt->handle);		lt->numfacs = rcf ? vzt_rd_get_32(&lt->numfacs,0) : 0;
-		rcf = fread(&lt->numfacbytes, 4, 1, lt->handle);	lt->numfacbytes = rcf ? vzt_rd_get_32(&lt->numfacbytes,0) : 0;
+
+		if(!lt->numfacs)
+			{
+			vztint32_t num_expansion_bytes;
+
+			rcf = fread(&num_expansion_bytes, 4, 1, lt->handle); num_expansion_bytes = rcf ? vzt_rd_get_32(&num_expansion_bytes,0) : 0;
+			rcf = fread(&lt->numfacs, 4, 1, lt->handle); lt->numfacs = rcf ? vzt_rd_get_32(&lt->numfacs,0) : 0;
+			if(num_expansion_bytes >= 8)
+				{
+				rcf = fread(&lt->timezero, 8, 1, lt->handle); lt->timezero = rcf ? vzt_rd_get_64(&lt->timezero,0) : 0;
+				if(num_expansion_bytes > 8)
+					{
+					/* future version? */
+					fseeko(lt->handle, num_expansion_bytes - 8, SEEK_CUR);
+					}
+				}
+				else
+				{
+				/* malformed */
+				fseeko(lt->handle, num_expansion_bytes, SEEK_CUR);
+				}
+			}
+
+		rcf = fread(&lt->numfacbytes, 4, 1, lt->handle); lt->numfacbytes = rcf ? vzt_rd_get_32(&lt->numfacbytes,0) : 0;
 		rcf = fread(&lt->longestname, 4, 1, lt->handle);	lt->longestname = rcf ? vzt_rd_get_32(&lt->longestname,0) : 0;
 		rcf = fread(&lt->zfacnamesize, 4, 1, lt->handle);	lt->zfacnamesize = rcf ? vzt_rd_get_32(&lt->zfacnamesize,0) : 0;
 		rcf = fread(&lt->zfacname_predec_size, 4, 1, lt->handle);lt->zfacname_predec_size = rcf ? vzt_rd_get_32(&lt->zfacname_predec_size,0) : 0;
