@@ -319,6 +319,13 @@ GLOBALS->paned_pack_semantics=atoi_64(str)?1:0;
 return(0);
 }
 
+int f_highlight_wavewindow(char *str)
+{
+DEBUG(printf("f_highlight_wavewindow(\"%s\")\n",str));
+GLOBALS->highlight_wavewindow=atoi_64(str)?1:0;
+return(0);
+}
+
 int f_ignore_savefile_pane_pos(char *str)
 {
 DEBUG(printf("f_ignore_savefile_pane_pos(\"%s\")\n",str));
@@ -488,13 +495,6 @@ GLOBALS->use_big_fonts=atoi_64(str)?1:0;
 return(0);
 }
 
-int f_use_full_precision(char *str)
-{
-DEBUG(printf("f_use_full_precision(\"%s\")\n",str));
-GLOBALS->use_full_precision=atoi_64(str)?1:0;
-return(0);
-}
-
 int f_use_frequency_display(char *str)
 {
 DEBUG(printf("f_use_frequency_display(\"%s\")\n",str));
@@ -502,6 +502,13 @@ GLOBALS->use_frequency_delta=atoi_64(str)?1:0;
 return(0);
 }
 
+int f_use_full_precision(char *str)
+{
+DEBUG(printf("f_use_full_precision(\"%s\")\n",str));
+GLOBALS->use_full_precision=atoi_64(str)?1:0;
+return(0);
+}
+
 int f_use_maxtime_display(char *str)
 {
 DEBUG(printf("f_use_maxtime_display(\"%s\")\n",str));
@@ -565,6 +572,13 @@ GLOBALS->use_standard_clicking=atoi_64(str)?1:0;
 return(0);
 }
 
+int f_use_standard_trace_select(char *str)
+{
+DEBUG(printf("f_f_use_standard_trace_select(\"%s\")\n",str));
+GLOBALS->use_standard_trace_select=atoi_64(str)?1:0;
+return(0);
+}
+
 int f_use_toolbutton_interface(char *str)
 {
 DEBUG(printf("f_use_toolbutton_interface(\"%s\")\n",str));
@@ -815,6 +829,7 @@ static struct rc_entry rcitems[]=
 { "hier_delimeter", f_hier_delimeter },
 { "hier_grouping", f_hier_grouping },
 { "hier_max_level", f_hier_max_level },
+{ "highlight_wavewindow", f_highlight_wavewindow },
 { "hpane_pack", f_hpane_pack },
 { "ignore_savefile_pane_pos", f_ignore_savefile_pane_pos },
 { "ignore_savefile_pos", f_ignore_savefile_pos },
@@ -848,6 +863,7 @@ static struct rc_entry rcitems[]=
 { "use_scrollbar_only", f_use_scrollbar_only },
 { "use_scrollwheel_as_y", f_use_scrollwheel_as_y },
 { "use_standard_clicking", f_use_standard_clicking },
+{ "use_standard_trace_select", f_use_standard_trace_select },
 { "use_toolbutton_interface", f_use_toolbutton_interface },
 { "vcd_explicit_zero_subscripts", f_vcd_explicit_zero_subscripts },
 { "vcd_preserve_glitches", f_vcd_preserve_glitches },
