@@ -1,5 +1,5 @@
 /*
- * Copyright (c) Tony Bybell 2008-2009.
+ * Copyright (c) Tony Bybell 2008-2012.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -1012,7 +1012,7 @@ if(objc==2)
         	{
 		for(i=0;i<l;i++)
 			{
-			one_entry = make_single_tcl_list_name(elem[i], NULL, 0);
+			one_entry = make_single_tcl_list_name(elem[i], NULL, 0, 1); /* keep range */
 			WAVE_OE_ME
 			}
                 free_2(elem);
@@ -1847,6 +1847,7 @@ if(i < GLOBALS->num_notebook_pages)
         GLOBALS->use_full_precision = g_old->use_full_precision;
         GLOBALS->show_base = g_old->show_base;
         GLOBALS->display_grid = g_old->display_grid;
+        GLOBALS->highlight_wavewindow = g_old->highlight_wavewindow;
         GLOBALS->disable_mouseover = g_old->disable_mouseover;
         GLOBALS->zoom_pow10_snap = g_old->zoom_pow10_snap;
                                          
